@@ -1,4 +1,4 @@
-from evm_wallet.types import ABI
 from web3.contract import AsyncContract, Contract
+from web3.types import ABI
 
 ContractMap = dict[str, AsyncContract | ABI | Contract]
